@@ -4,9 +4,13 @@
 #  PyVuka commands(import ModuleLink.toPyVuka as pyvuka) or access the PyVuka data directly
 #  (import data_obj as data).
 #-----------------------------------------------------------------------------------------
-from .. ModuleLink import toPyVuka as pyvuka
+try:
+    from .. ModuleLink import toPyVuka as pyvuka
+    from .. import Modules as IPI
+except:
+    from ModuleLink import toPyVuka as pyvuka
+    import Modules as IPI
 import os
-from .. import Modules as IPI
 import xml.etree.ElementTree as xmlio
 import base64
 import pack64
