@@ -31,7 +31,10 @@ import errno
 import multiprocessing
 import psutil
 import smtplib
-from .. import data_obj as data
+try:
+    from .. import data_obj as data
+except:
+    import data_obj as data
 import stat
 
 
