@@ -3,7 +3,10 @@ import xlrd
 import xlsxwriter as XL
 import xml.etree.ElementTree as xmlio
 import base64
-from . import plot, fitfxns, inputprocessing
+try:
+    from . import plot, fitfxns, inputprocessing
+except:
+    import plot, fitfxns, inputprocessing
 from matplotlib import pyplot as pl
 import os
 import chardet
